==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/P2SVpnServerConfigRadiusServerRootCertificateArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.P2SVpnServerConfigRadiusServerRootCertificateArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Radius Server root certificate of P2SVpnServerConfiguration.
 * @property etag A unique read-only string that changes whenever the resource is updated.
 * @property id Resource ID.
 * @property name The name of the resource that is unique within a resource group. This name can be used to access the resource.
 * @property publicCertData The certificate public data.
 */
public data class P2SVpnServerConfigRadiusServerRootCertificateArgs(
    public val etag: Output<String>? = null,
    public val id: Output<String>? = null,
    public val name: Output<String>? = null,
    public val publicCertData: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.network.inputs.P2SVpnServerConfigRadiusServerRootCertificateArgs> {
    override fun toJava():
        com.pulumi.azurenative.network.inputs.P2SVpnServerConfigRadiusServerRootCertificateArgs =
        com.pulumi.azurenative.network.inputs.P2SVpnServerConfigRadiusServerRootCertificateArgs.builder()
            .etag(etag?.applyValue({ args0 -> args0 }))
            .id(id?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .publicCertData(publicCertData.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [P2SVpnServerConfigRadiusServerRootCertificateArgs].
 */
@PulumiTagMarker
public class P2SVpnServerConfigRadiusServerRootCertificateArgsBuilder internal constructor() {
    private var etag: Output<String>? = null

    private var id: Output<String>? = null

    private var name: Output<String>? = null

    private var publicCertData: Output<String>? = null

    /**
     * @param value A unique read-only string that changes whenever the resource is updated.
     */
    @JvmName("ptwjywimijuvpuri")
    public suspend fun etag(`value`: Output<String>) {
        this.etag = value
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("wcwinolsrhxcjhkj")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    @JvmName("txxkbcrarexbdkmk")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The certificate public data.
     */
    @JvmName("cgcqydnwdvemxdoh")
    public suspend fun publicCertData(`value`: Output<String>) {
        this.publicCertData = value
    }

    /**
     * @param value A unique read-only string that changes whenever the resource is updated.
     */
    @JvmName("ucgvakofbvfahlpv")
    public suspend fun etag(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.etag = mapped
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("oqoxtgbwkawbahnl")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value The name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    @JvmName("itiwvvhjaifspuys")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The certificate public data.
     */
    @JvmName("oicgxfkmlljrbfba")
    public suspend fun publicCertData(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.publicCertData = mapped
    }

    internal fun build(): P2SVpnServerConfigRadiusServerRootCertificateArgs =
        P2SVpnServerConfigRadiusServerRootCertificateArgs(
            etag = etag,
            id = id,
            name = name,
            publicCertData = publicCertData ?: throw PulumiNullFieldException("publicCertData"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/P2SVpnServerConfigRadiusServerRootCertificateArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.P2SVpnServerConfigRadiusServerRootCertificateArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Radius Server root certificate of P2SVpnServerConfiguration.
 * @property etag A unique read-only string that changes whenever the resource is updated.
 * @property id Resource ID.
 * @property name The name of the resource that is unique within a resource group. This name can be used to access the resource.
 * @property publicCertData The certificate public data.
 */
public data class P2SVpnServerConfigRadiusServerRootCertificateArgs(
    public val etag: Output<String>? = null,
    public val id: Output<String>? = null,
    public val name: Output<String>? = null,
    public val publicCertData: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.network.inputs.P2SVpnServerConfigRadiusServerRootCertificateArgs> {
    override fun toJava():
        com.pulumi.azurenative.network.inputs.P2SVpnServerConfigRadiusServerRootCertificateArgs =
        com.pulumi.azurenative.network.inputs.P2SVpnServerConfigRadiusServerRootCertificateArgs.builder()
            .etag(etag?.applyValue({ args0 -> args0 }))
            .id(id?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .publicCertData(publicCertData.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [P2SVpnServerConfigRadiusServerRootCertificateArgs].
 */
@PulumiTagMarker
public class P2SVpnServerConfigRadiusServerRootCertificateArgsBuilder internal constructor() {
    private var etag: Output<String>? = null

    private var id: Output<String>? = null

    private var name: Output<String>? = null

    private var publicCertData: Output<String>? = null

    /**
     * @param value A unique read-only string that changes whenever the resource is updated.
     */
    @JvmName("quuxyvomgqkjchhb")
    public suspend fun etag(`value`: Output<String>) {
        this.etag = value
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("ttcnxcrynurbvaxb")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    @JvmName("wccqmcuriqsimiyh")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The certificate public data.
     */
    @JvmName("ootgyhrbdriihqui")
    public suspend fun publicCertData(`value`: Output<String>) {
        this.publicCertData = value
    }

    /**
     * @param value A unique read-only string that changes whenever the resource is updated.
     */
    @JvmName("hwsbmetdgehbyukg")
    public suspend fun etag(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.etag = mapped
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("hclxqqibbsavrhcq")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value The name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    @JvmName("uiieltvkvtogonqg")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The certificate public data.
     */
    @JvmName("jimfkxhiypqsjhny")
    public suspend fun publicCertData(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.publicCertData = mapped
    }

    internal fun build(): P2SVpnServerConfigRadiusServerRootCertificateArgs =
        P2SVpnServerConfigRadiusServerRootCertificateArgs(
            etag = etag,
            id = id,
            name = name,
            publicCertData = publicCertData ?: throw PulumiNullFieldException("publicCertData"),
        )
}
